function [L, U] = lu1( A )
%LU   LU-factorization of A
%   Computes lower matrix L and upper matrix U such that A = L*U.

	n = size(A, 1);
	L = zeros(n);
	
	% Transform A into upper triangular form
	for k = 1:n
		% Zero column?
		if all(abs(A(k:n, k)) < eps)
			% A is singular; return "false"
			L = false;
			U = false;
			return;
		end
		
		% Set the k-th column of L
		L(k+1:n, k) = A(k+1:n, k) / A(k,k);
				
		% Eliminate rest of column
		for l = k+1:n
			A(l,:) = A(l,:) - A(k,:)/A(k,k)*A(l,k);
		end
	end
	
	% Add the diagonal elements of L
	L = L + eye(n);

	% U is now the row-reduced form of A
	U = A;
end